==> 3.1.0.tar.gz: lib/src/constant/constant.dart <==
import 'dart:convert';
import 'dart:math';
import 'package:awesome_dialog/awesome_dialog.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:intl/intl.dart';
import 'package:pay_unit_sdk/src/blocs/pay_unit_stream.dart';
import '../../pay_unit_sdk.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

//production link
var baseUrl = "https://app.payunit.net/api";

var payUnitGreenColor = const Color(0xFF05AB9F);

NumberFormat getOcy() {
  final oCcy = NumberFormat("#,##0", "en_us");
  return oCcy;
}

makeToast(msg, context, greenLight) {
  Fluttertoast.showToast(
      msg: msg,
      toastLength: Toast.LENGTH_LONG,
      gravity: ToastGravity.TOP,
      timeInSecForIosWeb: 15,
      backgroundColor: greenLight,
      textColor: Colors.white,
      fontSize: 16.0);
}

getRandomId() {
  //initialize the Date of the day
  var now = DateTime.now();
  var rng = Random();
  //specify the format of the date
  var formatter = DateFormat('yyyyMMddHms');
  String formattedDate = "${formatter.format(now)}${rng.nextInt(100000)}";
  return formattedDate;
}

showInfoDialog(context, msg) {
  AwesomeDialog(
    dismissOnTouchOutside: false,
    context: context,
    animType: AnimType.SCALE,
    dialogType: DialogType.NO_HEADER,
    body: Center(
      child: Text(
        msg,
        style: const TextStyle(
            fontStyle: FontStyle.normal, fontWeight: FontWeight.bold),
        textAlign: TextAlign.center,
      ),
    ),
    btnOkOnPress: () async {},
    btnOkColor: payUnitGreenColor,
  ).show();
}

Widget buildPayUnitWidget(context) {
  return SizedBox(
    width: MediaQuery.of(context).size.width * 0.25,
    child: Image.network(
        "https://app.payunit.net/assets/img/static/pay_unit_logo_color.png"),
  );
}

Widget paymentComponent(
    bool displayError,
    context,
    transactionAmount,
    _formKey,
    _autoValidate,
    phoneController,
    X_API_KEY,
    transaction_id,
    transactionCallBackUrl,
    provider_short_tag,
    merchandPassword,
    merchandUserName,
    actionAfterProccess,
    Function isvalidPhoneState,
    String sandbox,
    String pspName,
    String imageUrl,
    ) {
  return Padding(
    padding: const EdgeInsets.only(left: 30, right: 30),
    child: Column(
      children: <Widget>[
        SizedBox(
          height: MediaQuery.of(context).size.height * 0.02,
        ),
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            GestureDetector(
              onTap: () {
                Navigator.of(context).pop();
              },
              child: const Icon(
                Icons.arrow_back_ios,
                color: Colors.black,
              ),
            ),
            const SizedBox(
              width: 15,
            ),
            SizedBox(
              width: MediaQuery.of(context).size.width * 0.12,
              child: Image.network(imageUrl),
            ),
            const SizedBox(
              width: 15,
            ),
            Text(
              pspName,
              style: const TextStyle(
                  color: Colors.black,
                  fontWeight: FontWeight.bold,
                  fontSize: 18),
            ),
            const SizedBox(
              width: 15,
            ),
            const SizedBox(
              width: 15,
            ),
            const SizedBox(
              width: 15,
            ),
            const SizedBox(
              width: 15,
            ),
          ],
        ),
        SizedBox(
          height: MediaQuery.of(context).size.height * 0.01,
        ),
        const Divider(
          color: Colors.black,
        ),
        SizedBox(
          height: MediaQuery.of(context).size.height * 0.02,
        ),
        Text(
          "Amount to pay",
          style: TextStyle(
              color: Colors.black,
              fontSize: MediaQuery.of(context).size.width * 0.045,
              fontWeight: FontWeight.w700),
        ),
        SizedBox(
          height: MediaQuery.of(context).size.height * 0.01,
        ),
        Text(
          "${getOcy().format((int.parse(transactionAmount)))} XAF",
          style: TextStyle(
              color: payUnitGreenColor,
              fontSize: 40,
              fontWeight: FontWeight.bold),
        ),
        SizedBox(
          height: MediaQuery.of(context).size.height * 0.015,
        ),
        Form(
          key: _formKey,
          autovalidateMode: AutovalidateMode.always,
          child: Column(
            children: [
              const SizedBox(height: 10),
              TextFormField(
                keyboardType: TextInputType.number,
                controller: phoneController,
                decoration: InputDecoration(
                  contentPadding: EdgeInsets.all(
                      MediaQuery.of(context).size.height * 0.020),
                  hintText: "Enter your phone number",
                  hintStyle: TextStyle(
                    color: Colors.grey,
                    fontWeight: FontWeight.bold,
                    fontSize: MediaQuery.of(context).size.width * 0.032,
                  ),
                  border: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(10.0),
                  ),
                  prefixIcon: Icon(
                    FontAwesomeIcons.phoneAlt,
                    color: payUnitGreenColor,
                    size: 20,
                  ),
                ),
                validator: (String? arg) {
                  if (arg!.isEmpty) {
                    return 'Enter a phone number';
                  } else if (arg.length < 9) {
                    return 'The phone number must be 9 digits , example: 6562090** ';
                  } else if (arg.length > 9) {
                    return 'The phone number must be 9 digits , example: 6562090** ';
                  } else
                    return null;
                },
              ),
              const SizedBox(height: 20),
              AnimButton(
                color: payUnitGreenColor,
                pressEvent: () {
                  /// verifier si les champs sont vide .
                  if (_formKey.currentState.validate()) {
                    // If all data are correct then save data to out variables
                    _formKey.currentState.save();
                    AwesomeDialog(
                        dismissOnBackKeyPress: false,
                        dismissOnTouchOutside: false,
                        context: context,
                        dialogType: DialogType.NO_HEADER,
                        animType: AnimType.BOTTOMSLIDE,
                        title: "Confirm",
                        desc: 'Do you confirm this payment',
                        btnOkColor: payUnitGreenColor,
                        btnOkText: "OK",
                        btnOkIcon: Icons.check,
                        btnOkOnPress: () {
                          //set the stream to true if the payment is running
                          // set the stream to false to visible this part of the code
                          // Navigator.pop(context);
                          payUnitStream.paymentSink.add(true);
                          // Navigator.pop(context);
                          ApiService api = ApiService();
                          api.makePayment(
                            paymentType: null,
                            X_API_KEY: X_API_KEY,
                            transactionAmount: transactionAmount,
                            transaction_id: transaction_id,
                            transactionCallBackUrl: transactionCallBackUrl,
                            phoneNumber: phoneController.text,
                            provider_short_tag: provider_short_tag,
                            merchandPassword: merchandPassword,
                            merchandUserName: merchandUserName,
                            context: context,
                            currency: "XAF",
                            actionAfterProccess: actionAfterProccess,
                            mode: sandbox,
                            userName: '',
                          );
                        },
                        btnCancelOnPress: () {},
                        btnCancelColor: Colors.red,
                        btnCancelIcon: Icons.cancel,
                        btnCancelText: 'Cancel')
                        .show();
                  } else {
                    //If all data are not valid then start auto validation.
                    isvalidPhoneState();
                  }
                },
                text: 'CONTINUE',
                icon: null,
              )
            ],
          ),
        ),
        SizedBox(
          height: MediaQuery.of(context).size.height * 0.05,
        ),
        buildPayUnitWidget(context),
        Visibility(
          visible: displayError,
          child: const Text(
            "Hummm something didn't work, please retry ",
            style: TextStyle(color: Colors.red, fontSize: 12),
            textAlign: TextAlign.center,
          ),
        )
      ],
    ),
  );
}

void closeAndToastPaymentAreMake(context) {
  Navigator.of(context).pop();
  makeToast("Your transaction has been initiated", context, Colors.blue);
}

String getEncode(String apiUserNameAndPassWord) {
  String credentials = apiUserNameAndPassWord;
  Codec<String, String> stringToBase64 = utf8.fuse(base64);
  String encoded = stringToBase64.encode(credentials);
  return encoded;
}

getGlobalHeader(String X_API_KEY, String apiUserNameAndPassWord, String mode) {
  return {
    'Authorization': 'Basic ${getEncode(apiUserNameAndPassWord)}',
    'Content-Type': 'application/json',
    'X-API-KEY': X_API_KEY,
    'mode': mode,
  };
}

==> 3.1.3.tar.gz: lib/src/constant/constant.dart <==
import 'dart:convert';
import 'dart:math';
import 'package:awesome_dialog/awesome_dialog.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:intl/intl.dart';
import '../api_services.dart';
import '../blocs/pay_unit_stream.dart';
import '../pay_unit_button.dart';


//production link
var baseUrl = "https://app.payunit.net/api";

var payUnitGreenColor = const Color(0xFF05AB9F);

NumberFormat getOcy() {
  final oCcy = NumberFormat("#,##0", "en_us");
  return oCcy;
}

makeToast(msg, context, greenLight) {
  Fluttertoast.showToast(
      msg: msg,
      toastLength: Toast.LENGTH_LONG,
      gravity: ToastGravity.TOP,
      timeInSecForIosWeb: 15,
      backgroundColor: greenLight,
      textColor: Colors.white,
      fontSize: 16.0);
}

getRandomId() {
  //initialize the Date of the day
  var now = DateTime.now();
  var rng = Random();
  //specify the format of the date
  var formatter = DateFormat('yyyyMMddHms');
  String formattedDate = "${formatter.format(now)}${rng.nextInt(100000)}";
  return formattedDate;
}

showInfoDialog(context, msg) {
  AwesomeDialog(
    dismissOnTouchOutside: false,
    context: context,
    animType: AnimType.SCALE,
    dialogType: DialogType.NO_HEADER,
    body: Center(
      child: Text(
        msg,
        style: const TextStyle(
            fontStyle: FontStyle.normal, fontWeight: FontWeight.bold),
        textAlign: TextAlign.center,
      ),
    ),
    btnOkOnPress: () async {},
    btnOkColor: payUnitGreenColor,
  ).show();
}

Widget buildPayUnitWidget(context) {
  return SizedBox(
    width: MediaQuery.of(context).size.width * 0.25,
    child: Image.network(
        "https://app.payunit.net/assets/img/static/pay_unit_logo_color.png"),
  );
}

Widget paymentComponent(
    bool displayError,
    context,
    transactionAmount,
    _formKey,
    _autoValidate,
    phoneController,
    xApiKey,
    transaction_id,
    transactionCallBackUrl,
    provider_short_tag,
    merchandPassword,
    merchandUserName,
    actionAfterProccess,
    Function isvalidPhoneState,
    String sandbox,
    String pspName,
    String imageUrl,
    ) {
  return Padding(
    padding: const EdgeInsets.only(left: 30, right: 30),
    child: Column(
      children: <Widget>[
        SizedBox(
          height: MediaQuery.of(context).size.height * 0.02,
        ),
        Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            GestureDetector(
              onTap: () {
                Navigator.of(context).pop();
              },
              child: const Icon(
                Icons.arrow_back_ios,
                color: Colors.black,
              ),
            ),
            const SizedBox(
              width: 15,
            ),
            SizedBox(
              width: MediaQuery.of(context).size.width * 0.12,
              child: Image.network(imageUrl),
            ),
            const SizedBox(
              width: 15,
            ),
            Text(
              pspName,
              style: const TextStyle(
                  color: Colors.black,
                  fontWeight: FontWeight.bold,
                  fontSize: 18),
            ),
            const SizedBox(
              width: 15,
            ),
            const SizedBox(
              width: 15,
            ),
            const SizedBox(
              width: 15,
            ),
            const SizedBox(
              width: 15,
            ),
          ],
        ),
        SizedBox(
          height: MediaQuery.of(context).size.height * 0.01,
        ),
        const Divider(
          color: Colors.black,
        ),
        SizedBox(
          height: MediaQuery.of(context).size.height * 0.02,
        ),
        Text(
          "Amount to pay",
          style: TextStyle(
              color: Colors.black,
              fontSize: MediaQuery.of(context).size.width * 0.045,
              fontWeight: FontWeight.w700),
        ),
        SizedBox(
          height: MediaQuery.of(context).size.height * 0.01,
        ),
        Text(
          "${getOcy().format((int.parse(transactionAmount)))} XAF",
          style: TextStyle(
              color: payUnitGreenColor,
              fontSize: 40,
              fontWeight: FontWeight.bold),
        ),
        SizedBox(
          height: MediaQuery.of(context).size.height * 0.015,
        ),
        Form(
          key: _formKey,
          autovalidateMode: AutovalidateMode.always,
          child: Column(
            children: [
              const SizedBox(height: 10),
              TextFormField(
                keyboardType: TextInputType.number,
                controller: phoneController,
                decoration: InputDecoration(
                  contentPadding: EdgeInsets.all(
                      MediaQuery.of(context).size.height * 0.020),
                  hintText: "Enter your phone number",
                  hintStyle: TextStyle(
                    color: Colors.grey,
                    fontWeight: FontWeight.bold,
                    fontSize: MediaQuery.of(context).size.width * 0.032,
                  ),
                  border: OutlineInputBorder(
                    borderRadius: BorderRadius.circular(10.0),
                  ),
                  prefixIcon: Icon(
                    FontAwesomeIcons.phoneAlt,
                    color: payUnitGreenColor,
                    size: 20,
                  ),
                ),
                validator: (String? arg) {
                  if (arg!.isEmpty) {
                    return 'Enter a phone number';
                  } else if (arg.length < 9) {
                    return 'The phone number must be 9 digits , example: 6562090** ';
                  } else if (arg.length > 9) {
                    return 'The phone number must be 9 digits , example: 6562090** ';
                  } else
                    return null;
                },
              ),
              const SizedBox(height: 20),
              AnimButton(
                color: payUnitGreenColor,
                pressEvent: () {
                  /// verifier si les champs sont vide .
                  if (_formKey.currentState.validate()) {
                    // If all data are correct then save data to out variables
                    _formKey.currentState.save();
                    AwesomeDialog(
                        dismissOnBackKeyPress: false,
                        dismissOnTouchOutside: false,
                        context: context,
                        dialogType: DialogType.NO_HEADER,
                        animType: AnimType.BOTTOMSLIDE,
                        title: "Confirm",
                        desc: 'Do you confirm this payment',
                        btnOkColor: payUnitGreenColor,
                        btnOkText: "OK",
                        btnOkIcon: Icons.check,
                        btnOkOnPress: () {
                          //set the stream to true if the payment is running
                          // set the stream to false to visible this part of the code
                          // Navigator.pop(context);
                          payUnitStream.paymentSink.add(true);
                          // Navigator.pop(context);
                          ApiService api = ApiService();
                          api.makePayment(
                            paymentType: null,
                            xApiKey: xApiKey,
                            transactionAmount: transactionAmount,
                            transaction_id: transaction_id,
                            transactionCallBackUrl: transactionCallBackUrl,
                            phoneNumber: phoneController.text,
                            provider_short_tag: provider_short_tag,
                            merchandPassword: merchandPassword,
                            merchandUserName: merchandUserName,
                            context: context,
                            currency: "XAF",
                            actionAfterProccess: actionAfterProccess,
                            mode: sandbox,
                            userName: '',
                          );
                        },
                        btnCancelOnPress: () {},
                        btnCancelColor: Colors.red,
                        btnCancelIcon: Icons.cancel,
                        btnCancelText: 'Cancel')
                        .show();
                  } else {
                    //If all data are not valid then start auto validation.
                    isvalidPhoneState();
                  }
                },
                text: 'CONTINUE',
                icon: null,
              )
            ],
          ),
        ),
        SizedBox(
          height: MediaQuery.of(context).size.height * 0.05,
        ),
        buildPayUnitWidget(context),
        Visibility(
          visible: displayError,
          child: const Text(
            "Hummm something didn't work, please retry ",
            style: TextStyle(color: Colors.red, fontSize: 12),
            textAlign: TextAlign.center,
          ),
        )
      ],
    ),
  );
}

void closeAndToastPaymentAreMake(context) {
  Navigator.of(context).pop();
  makeToast("Your transaction has been initiated", context, Colors.blue);
}

String getEncode(String apiUserNameAndPassWord) {
  String credentials = apiUserNameAndPassWord;
  Codec<String, String> stringToBase64 = utf8.fuse(base64);
  String encoded = stringToBase64.encode(credentials);
  return encoded;
}

getGlobalHeader(String xApiKey, String apiUserNameAndPassWord, String mode) {
  return {
    'Authorization': 'Basic ${getEncode(apiUserNameAndPassWord)}',
    'Content-Type': 'application/json',
    'X-API-KEY': xApiKey,
    'mode': mode,
  };
}
